# CMRR-MB in Python
rewrite Matlab's extractCMRRPhysio.m(https://github.com/CMRR-C2P/MB/blob/master/extractCMRRPhysio.m) in Python',

install:  
```bash
pip install git+https://github.com/yinglilu/extractCMRRPhysio.git#egg=extractCMRRPhysio
```
or   
```bash
pip install extractCMRRPhysio
```

usage: 

```bash
extractCMRRPhysio /path/to/dicom_file /output_path
```
